package [% module %];
use strict;

use warnings;
no warnings;

use subs qw();
use vars qw($VERSION);

$VERSION = '0.11';

=head1 NAME

[% module %] - [% description %]

=head1 SYNOPSIS

	use [% module %];

=head1 DESCRIPTION

=over 4

=cut

=item new

=cut

sub new {
	
	}
	
=item init

=cut

sub init {
	
	}


=back

=head1 TO DO


=head1 SEE ALSO


=head1 SOURCE AVAILABILITY

This source is in a Git repository that I haven't made public
because I haven't bothered to set it up. If you want to clone
it, just ask and we'll work something out.

=head1 AUTHOR

brian d foy, C<< <bdfoy@cpan.org> >>

=head1 COPYRIGHT AND LICENSE

Copyright (c) [% year %], brian d foy, All Rights Reserved.

You may redistribute this under the same terms as Perl itself.

=cut

1;
